@@ -1,12 +1,12 @@
 /// Return a list of all non empty and unique combinations
 pub fn generate_list_of_all_combinations(n: usize) -> Vec<Vec<usize>> {
     let mut result = Vec::with_capacity((2 << n) - 1);
-    let mut current = Vec::new();
-    generate_indeses_combination(n, 0, &mut current, &mut result);
+    let mut current = Vec::with_capacity(n);
+    generate_indices_combination(n, 0, &mut current, &mut result);
     result
 }
 
-fn generate_indeses_combination(
+fn generate_indices_combination(
     n: usize,
     start: usize,
     current: &mut Vec<usize>,
@@ -18,7 +18,7 @@ fn generate_indeses_combination(
 
     for i in start..n {
         current.push(i);
-        generate_indeses_combination(n, i + 1, current, result);
+        generate_indices_combination(n, i + 1, current, result);
         current.pop();
     }
 }
