@@ -1,6 +1,6 @@
 use std::collections::HashMap;
 
-use gitql_ast::types::base::DataType;
+use gitql_ast::types::DataType;
 
 use crate::schema::Schema;
 use crate::signature::AggregationFunction;
@@ -8,7 +8,7 @@ use crate::signature::Signature;
 use crate::signature::StandardFunction;
 use crate::signature::WindowFunction;
 use crate::types_table::TypesTable;
-use crate::values::base::Value;
+use crate::values::Value;
 
 /// Environment that track schema, functions, scopes and types
 /// to be used in different places in the query engine
@@ -89,10 +89,10 @@ impl Environment {
     pub fn with_window_functions(
         &mut self,
         signatures: &HashMap<&'static str, Signature>,
-        aggregation: &HashMap<&'static str, WindowFunction>,
+        window: &HashMap<&'static str, WindowFunction>,
     ) {
         self.window_signatures.extend(signatures.to_owned());
-        self.window_functions.extend(aggregation.to_owned());
+        self.window_functions.extend(window.to_owned());
     }
 
     /// Register new Modified Types table
