@@ -11,20 +11,21 @@ pub(crate) fn apply_filter_operation(
     env: &mut Environment,
     condition: &Box<dyn Expr>,
     titles: &[String],
-    objects: &Vec<Row>,
-) -> Result<Vec<Row>, String> {
-    let mut rows: Vec<Row> = vec![];
-
-    for object in objects {
-        let expression = evaluate_expression(env, condition, titles, &object.values)?;
+    rows: &mut Vec<Row>,
+) -> Result<(), String> {
+    let mut positions_to_delete = vec![];
+    for (index, row) in rows.iter().enumerate() {
+        let expression = evaluate_expression(env, condition, titles, &row.values)?;
         if let Some(bool_value) = expression.as_any().downcast_ref::<BoolValue>() {
-            if bool_value.value {
-                rows.push(Row {
-                    values: object.values.clone(),
-                });
+            if !bool_value.value {
+                positions_to_delete.push(index);
             }
         }
     }
 
-    Ok(rows)
+    for position in positions_to_delete.iter().rev() {
+        rows.remove(*position);
+    }
+
+    Ok(())
 }
