@@ -2,24 +2,24 @@ use crate::diagnostic::Diagnostic;
 use crate::token::SourceLocation;
 use crate::token::Token;
 use crate::token::TokenKind;
+use crate::token::GITQL_RESERVED_KEYWORDS;
 
-pub struct Tokenizer {
-    pub(crate) content: Vec<char>,
-    pub(crate) content_len: usize,
-    pub(crate) index: usize,
+pub struct Tokenizer<'a> {
+    content: &'a [char],
+    content_len: usize,
+    index: usize,
 
-    pub(crate) line_start: u32,
-    pub(crate) line_end: u32,
-    pub(crate) column_start: u32,
-    pub(crate) column_end: u32,
+    line_start: u32,
+    line_end: u32,
+    column_start: u32,
+    column_end: u32,
 }
 
-impl Tokenizer {
-    pub(crate) fn new(chars: Vec<char>) -> Tokenizer {
-        let content_len = chars.len();
+impl<'a> Tokenizer<'a> {
+    pub(crate) fn new(chars: &'a [char]) -> Tokenizer<'a> {
         Tokenizer {
             content: chars,
-            content_len,
+            content_len: chars.len(),
             index: 0,
 
             line_start: 1,
@@ -29,9 +29,9 @@ impl Tokenizer {
         }
     }
 
-    pub fn tokenize(content: String) -> Result<Vec<Token>, Box<Diagnostic>> {
-        let mut tokenizer = Tokenizer::new(content.chars().collect());
-        tokenizer.tokenize_characters()
+    pub fn tokenize(chars: &'a str) -> Result<Vec<Token>, Box<Diagnostic>> {
+        let chars: Vec<char> = chars.chars().collect();
+        Tokenizer::new(&chars).tokenize_characters()
     }
 
     fn current_source_location(&self) -> SourceLocation {
@@ -62,7 +62,7 @@ impl Tokenizer {
             // @> or Global Variable Symbol
             if char == '@' {
                 // @>
-                if self.index + 1 < len && self.content[self.index + 1] == '>' {
+                if self.is_next_char('>') {
                     self.index += 2;
                     let location = self.current_source_location();
                     tokens.push(Token::new(TokenKind::AtRightArrow, location));
@@ -76,25 +76,32 @@ impl Tokenizer {
             // Number
             if char.is_numeric() {
                 if char == '0' && self.index + 1 < len {
-                    if self.content[self.index + 1] == 'x' {
-                        self.index += 2;
-                        self.column_start += 2;
-                        tokens.push(self.consume_hex_number()?);
-                        continue;
-                    }
-
-                    if self.content[self.index + 1] == 'b' {
-                        self.index += 2;
-                        self.column_start += 2;
-                        tokens.push(self.consume_binary_number()?);
-                        continue;
-                    }
-
-                    if self.content[self.index + 1] == 'o' {
-                        self.index += 2;
-                        self.column_start += 2;
-                        tokens.push(self.consume_octal_number()?);
-                        continue;
+                    match self.content[self.index + 1] {
+                        // bindigits
+                        'b' | 'B' => {
+                            self.index += 2;
+                            self.column_start += 2;
+                            tokens.push(self.consume_binary_number()?);
+                            continue;
+                        }
+                        // hexdigits
+                        'x' | 'X' => {
+                            self.index += 2;
+                            self.column_start += 2;
+                            tokens.push(self.consume_hex_number()?);
+                            continue;
+                        }
+                        // octdigits
+                        'o' | 'O' => {
+                            self.index += 2;
+                            self.column_start += 2;
+                            tokens.push(self.consume_octal_number()?);
+                            continue;
+                        }
+                        _ => {
+                            tokens.push(self.consume_number()?);
+                            continue;
+                        }
                     }
                 }
 
@@ -131,8 +138,8 @@ impl Tokenizer {
             // Minus
             if char == '-' {
                 // Ignore single line comment which from -- until the end of the current line
-                if self.index + 1 < self.content_len && self.content[self.index + 1] == '-' {
-                    self.ignore_single_line_comment();
+                if self.is_next_char('-') {
+                    self.consume_single_line_comment();
                     continue;
                 }
 
@@ -153,8 +160,8 @@ impl Tokenizer {
             // Slash
             if char == '/' {
                 // Ignore C style comment which from /* comment */
-                if self.index + 1 < self.content_len && self.content[self.index + 1] == '*' {
-                    self.ignore_c_style_comment()?;
+                if self.is_next_char('*') {
+                    self.consume_c_style_block_comment()?;
                     continue;
                 }
 
@@ -193,7 +200,7 @@ impl Tokenizer {
                 let location = self.current_source_location();
 
                 self.advance();
-                let kind = if self.index < len && self.content[self.index] == '|' {
+                let kind = if self.is_current_char('|') {
                     self.advance();
                     TokenKind::OrOr
                 } else {
@@ -209,7 +216,7 @@ impl Tokenizer {
                 let location = self.current_source_location();
 
                 self.advance();
-                let kind = if self.index < len && self.content[self.index] == '&' {
+                let kind = if self.is_current_char('&') {
                     self.advance();
                     TokenKind::AndAnd
                 } else {
@@ -249,10 +256,10 @@ impl Tokenizer {
                 let location = self.current_source_location();
 
                 self.advance();
-                let kind = if self.index < len && self.content[self.index] == '=' {
+                let kind = if self.is_current_char('=') {
                     self.advance();
                     TokenKind::GreaterEqual
-                } else if self.index < len && self.content[self.index] == '>' {
+                } else if self.is_current_char('>') {
                     self.advance();
                     TokenKind::BitwiseRightShift
                 } else {
@@ -268,21 +275,21 @@ impl Tokenizer {
                 let location = self.current_source_location();
 
                 self.advance();
-                let kind = if self.index < len && self.content[self.index] == '=' {
+                let kind = if self.is_current_char('=') {
                     self.advance();
-                    if self.index < len && self.content[self.index] == '>' {
+                    if self.is_current_char('>') {
                         self.advance();
                         TokenKind::NullSafeEqual
                     } else {
                         TokenKind::LessEqual
                     }
-                } else if self.index < len && self.content[self.index] == '<' {
+                } else if self.is_current_char('<') {
                     self.advance();
                     TokenKind::BitwiseLeftShift
-                } else if self.index < len && self.content[self.index] == '>' {
+                } else if self.is_current_char('>') {
                     self.advance();
                     TokenKind::BangEqual
-                } else if self.index < len && self.content[self.index] == '@' {
+                } else if self.is_current_char('@') {
                     self.advance();
                     TokenKind::ArrowRightAt
                 } else {
@@ -306,7 +313,7 @@ impl Tokenizer {
                 let location = self.current_source_location();
 
                 // :=
-                if self.index + 1 < len && self.content[self.index + 1] == '=' {
+                if self.is_next_char('=') {
                     tokens.push(Token::new(TokenKind::ColonEqual, location));
                     // Advance `:=`
                     self.advance_n(2);
@@ -314,7 +321,7 @@ impl Tokenizer {
                 }
 
                 // ::
-                if self.index + 1 < len && self.content[self.index + 1] == ':' {
+                if self.is_next_char(':') {
                     tokens.push(Token::new(TokenKind::ColonColon, location));
                     // Advance `::`
                     self.advance_n(2);
@@ -332,7 +339,7 @@ impl Tokenizer {
 
                 // Consume `!`
                 self.advance();
-                let kind = if self.index < len && self.content[self.index] == '=' {
+                let kind = if self.is_current_char('=') {
                     // Consume `=`
                     self.advance();
                     TokenKind::BangEqual
@@ -412,7 +419,7 @@ impl Tokenizer {
         self.advance();
 
         // Make sure first character is  alphabetic
-        if self.has_next() && !self.content[self.index].is_alphabetic() {
+        if !self.is_current_char_func(|c| c.is_alphanumeric()) {
             return Err(Diagnostic::error(
                 "Global variable name must start with alphabetic character",
             )
@@ -421,7 +428,7 @@ impl Tokenizer {
             .as_boxed());
         }
 
-        while self.has_next() && self.is_current_char_func(|c| c == '_' || c.is_alphanumeric()) {
+        while self.is_current_char_func(|c| c == '_' || c.is_alphanumeric()) {
             self.advance();
         }
 
@@ -436,8 +443,7 @@ impl Tokenizer {
 
     fn consume_identifier(&mut self) -> Token {
         let start_index = self.index;
-
-        while self.has_next() && self.is_current_char_func(|c| c == '_' || c.is_alphanumeric()) {
+        while self.is_current_char_func(|c| c == '_' || c.is_alphanumeric()) {
             self.advance();
         }
 
@@ -446,8 +452,11 @@ impl Tokenizer {
         let mut string: String = literal.iter().collect();
         string = string.to_lowercase();
 
-        let location = self.current_source_location();
-        Token::new_symbol(string, location)
+        let kind = GITQL_RESERVED_KEYWORDS
+            .get(string.as_str())
+            .cloned()
+            .unwrap_or(TokenKind::Symbol(string));
+        Token::new(kind, self.current_source_location())
     }
 
     fn consume_backticks_identifier(&mut self) -> Result<Token, Box<Diagnostic>> {
@@ -456,7 +465,7 @@ impl Tokenizer {
         // Advance '`'
         self.advance();
 
-        while self.has_next() && !self.is_current_char('`') {
+        while !self.is_current_char('`') {
             self.advance();
         }
 
@@ -479,16 +488,16 @@ impl Tokenizer {
     fn consume_number(&mut self) -> Result<Token, Box<Diagnostic>> {
         let start_index = self.index;
 
-        while self.has_next() && self.is_current_char_func(|c| c == '_' || c.is_numeric()) {
+        while self.is_current_char_func(|c| c == '_' || c.is_numeric()) {
             self.advance();
         }
 
         let mut is_float_value = false;
-        if self.has_next() && self.is_current_char('.') {
+        if self.is_current_char('.') {
             self.advance();
 
             is_float_value = true;
-            while self.has_next() && self.is_current_char_func(|c| c == '_' || c.is_numeric()) {
+            while self.is_current_char_func(|c| c == '_' || c.is_numeric()) {
                 self.advance();
             }
         }
@@ -527,14 +536,11 @@ impl Tokenizer {
 
     fn consume_binary_number(&mut self) -> Result<Token, Box<Diagnostic>> {
         let start_index = self.index;
-        let mut has_digit = false;
-
-        while self.has_next() && self.is_current_char_func(|c| c == '_' || c == '0' || c >= '1') {
+        while self.is_current_char_func(|c| c == '_' || c == '0' || c >= '1') {
             self.advance();
-            has_digit = true;
         }
 
-        if !has_digit {
+        if start_index == self.index {
             return Err(
                 Diagnostic::error("Missing digits after the integer base prefix")
                     .add_help("Expect at least one binary digits after the prefix 0b")
@@ -567,15 +573,11 @@ impl Tokenizer {
 
     fn consume_octal_number(&mut self) -> Result<Token, Box<Diagnostic>> {
         let start_index = self.index;
-        let mut has_digit = false;
-
-        while self.has_next() && self.is_current_char_func(|c| c == '_' || ('0'..='8').contains(&c))
-        {
+        while self.is_current_char_func(|c| c == '_' || ('0'..='8').contains(&c)) {
             self.advance();
-            has_digit = true;
         }
 
-        if !has_digit {
+        if start_index == self.index {
             return Err(
                 Diagnostic::error("Missing digits after the integer base prefix")
                     .add_help("Expect at least one octal digits after the prefix 0o")
@@ -589,7 +591,7 @@ impl Tokenizer {
         let string: String = literal.iter().collect();
         let literal_num = string.replace('_', "");
 
-        const OCTAL_RADIX: u32 = 2;
+        const OCTAL_RADIX: u32 = 8;
         match i64::from_str_radix(&literal_num, OCTAL_RADIX) {
             Ok(integer) => {
                 let location = self.current_source_location();
@@ -608,14 +610,11 @@ impl Tokenizer {
 
     fn consume_hex_number(&mut self) -> Result<Token, Box<Diagnostic>> {
         let start_index = self.index;
-        let mut has_digit = false;
-
-        while self.has_next() && self.is_current_char_func(|c| c == '_' || c.is_ascii_hexdigit()) {
+        while self.is_current_char_func(|c| c == '_' || c.is_ascii_hexdigit()) {
             self.advance();
-            has_digit = true;
         }
 
-        if !has_digit {
+        if start_index == self.index {
             return Err(
                 Diagnostic::error("Missing digits after the integer base prefix")
                     .add_help("Expect at least one hex digits after the prefix 0x")
@@ -683,7 +682,7 @@ impl Tokenizer {
         self.advance();
 
         let mut buffer = String::new();
-        while self.has_next() && self.content[self.index] != around {
+        while !self.is_current_char(around) {
             if !self.is_current_char('\\') {
                 buffer.push(self.content[self.index]);
                 self.advance();
@@ -742,11 +741,11 @@ impl Tokenizer {
         Ok(buffer)
     }
 
-    fn ignore_single_line_comment(&mut self) {
+    fn consume_single_line_comment(&mut self) {
         // Advance `--`
         self.advance_n(2);
 
-        while self.has_next() && !self.is_current_char('\n') {
+        while !self.is_current_char('\n') {
             self.advance();
         }
 
@@ -756,15 +755,25 @@ impl Tokenizer {
         self.column_end = 0;
     }
 
-    fn ignore_c_style_comment(&mut self) -> Result<(), Box<Diagnostic>> {
+    fn consume_c_style_block_comment(&mut self) -> Result<(), Box<Diagnostic>> {
         // Advance `/*`
         self.advance_n(2);
 
-        while self.index + 1 < self.content_len
-            && (!self.is_current_char('*') && self.content[self.index + 1] != '/')
-        {
+        let mut number_nested_block_start = 0;
+        loop {
+            if self.is_current_char('/') && self.is_next_char('*') {
+                number_nested_block_start += 1;
+            }
+
             // Advance char
             self.advance();
+
+            if self.is_current_char('*') && self.is_next_char('/') {
+                number_nested_block_start -= 1;
+                if number_nested_block_start < 0 {
+                    break;
+                }
+            }
         }
 
         if self.index + 2 > self.content_len {
@@ -790,11 +799,15 @@ impl Tokenizer {
     }
 
     fn is_current_char(&self, ch: char) -> bool {
-        self.content[self.index] == ch
+        self.index < self.content_len && self.content[self.index] == ch
+    }
+
+    fn is_next_char(&self, ch: char) -> bool {
+        self.index + 1 < self.content_len && self.content[self.index + 1] == ch
     }
 
     fn is_current_char_func(&self, func: fn(char) -> bool) -> bool {
-        func(self.content[self.index])
+        self.index < self.content_len && func(self.content[self.index])
     }
 
     fn has_next(&self) -> bool {
