@@ -18,11 +18,11 @@ use gitql_ast::types::variant::VariantType;
 use gitql_core::signature::AggregationFunction;
 use gitql_core::signature::Signature;
 use gitql_core::values::array::ArrayValue;
-use gitql_core::values::base::Value;
 use gitql_core::values::boolean::BoolValue;
 use gitql_core::values::integer::IntValue;
 use gitql_core::values::null::NullValue;
 use gitql_core::values::text::TextValue;
+use gitql_core::values::Value;
 
 use crate::meta_types::array_of_type;
 use crate::meta_types::first_element_type;
